![T-Rex](t_rex_typer/resources/trex_w_board_96.png) *Exercise your shorthand!*

# T-Rex Typer
The T-Rex Typer is a desktop application used to improve steno
writing.  It aims to provide textual as well as aural based learning.


# Development note
The T-Rex Typer is not yet ready!  I intended to make the repo public
only on alpha. However, this project is also meant as a profile piece
and it can serve that function today.  So, stay tuned and please
reach out if you're interested.
